abacusai.indexing_config — AbacusAI documentation

# `abacusai.indexing_config`

## Module Contents

### Classes

`IndexingConfig` | The indexing config for a Feature Group

class abacusai.indexing_config.IndexingConfig(client, primaryKey=None, updateTimestampKey=None, lookupKeys=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The indexing config for a Feature Group

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - primaryKey (str) – A single key index

    - updateTimestampKey (str) – The primary timestamp feature

    - lookupKeys (list of string) – A multi-key index. Cannot be used in conjuction with primary key.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict